================
Auto Directories
================

|build-status| |documentation-status| |PyPI|

.. |build-status| image:: https://github.com/pushkarkadam/autodirs/workflows/Python%20application/badge.svg
   :target: https://github.com/pushkarkadam/autodirs/actions

.. |documentation-status| image:: https://readthedocs.org/projects/autodirs/badge/?version=latest
   :target: https://autodirs.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

.. |PyPI| image:: https://img.shields.io/pypi/v/autodirs.svg
   :target: https://pypi.org/project/autodirs/

A python project to automatically generate directories and sub-directories.

Features
--------

- Create directories from text files
- Group by text Files
- Create directories from list

Installation
------------

Install autodirs by running:

``pip install autodirs``

License
-------

`MIT`_ (c) 2020 Pushkar Kadam

.. _MIT: LICENSE
